==> xmapcore_1.6.2.tar.gz: xmapcore/inst/unitTests/runit.all-statements.R <==
# Testing all of the statements (to make sure none of them crash)
# Testing for acutal responses is more tricky, as the responses may change from one
# release to the next...

if(FALSE) {
  library( "RUnit" )
  library( "xmapcore" )
}

###############################################################################
## Utility methods
##
.get.functions = function( func.type, func.pattern, min.len, name.build.function ) {
	.functions = ls( envir=xmapcore:::.xmap.queries )
	.queries = strsplit( .functions[ grep( func.pattern, .functions ) ], '\\.' )
	checkTrue( length( .queries ) >= min.len, paste( "Should have at least ", min.len, " '", func.type, "' functions", sep="" ) )
	r = lapply( .queries, function(i) {
		name = name.build.function( i )
		c( name, getFunction( name ) )
	} )
	r
}

.run.full.test.suite = function() {
	1 == length( grep( 'picr.man.ac.uk', Sys.info()[ 'nodename' ] ) )
}

.run.functions = function( functions, executor ) {
	lapply( c( 'hs-test', 'mm-test', 'rn-test', 'pb-test' ), function( db ) {
		data = tryCatch( xmap.connect( db ), error=function(e) { FALSE } )
		if( length( data ) == 1 ) {
			print( paste( "Cannot find datasource '", db, "', so skipping these tests.", sep="" ) )
		}
		else {
			# Set this to true if this species has no arrays
			no.arrays = is.null( all.arrays( as.vector=F ) )
			lapply( functions, function( func ) {
				if( no.arrays && length( grep( "array|probe|hit|est_|prediction", func[[1]] ) ) == 1 ) {
					print( paste( "Skipping", func[[1]], "on", xmapcore:::.xmap.internals$db.name ) )
				}
				else {
					print( paste( "Running", func[[1]], "on", xmapcore:::.xmap.internals$db.name ) )
					tryCatch( executor( func[[1]], func[[2]] ), error=function(e) {
						traceback()
						print( e )
					} )
				}
			} )
		}
	} )
}

###############################################################################
## SetUp is called before each test method
##
.setUp = function() {
}

###############################################################################
## TearDown is called after each test method
##
.tearDown = function() {
	xmap.disconnect()
}

test.gotsomefunctions = function() {
  checkTrue( length( ls( envir=xmapcore:::.xmap.queries ) ) >= 96, "Should have at least 96 functions" )
}

test.all.queries = function() {
	if( .run.full.test.suite() ) {
		# Get all 'all' functions (of which there should be at least 14)
		.functions = .get.functions( 'all', '\\.all$', 14, function(i) { paste( 'all.', i[1], 's', sep="" ) } )
		# And run them, checking that we get at least one result from each
		.run.functions( .functions, function( name, f ) { r = f() ; checkTrue( length( r ) > 0, "Got no results!!" ) } )
	}
	else {
		print( '\nSkipping all.XXX tests, as not on a PICR machine' )
	}
}

==> xmapcore_1.12.0.tar.gz: xmapcore/inst/unitTests/runit.all-statements.R <==
# Testing all of the statements (to make sure none of them crash)
# Testing for acutal responses is more tricky, as the responses may change from one
# release to the next...

if(FALSE) {
  library( "RUnit" )
  library( "xmapcore" )
}

###############################################################################
## Utility methods
##
.get.functions = function( func.type, func.pattern, min.len, name.build.function ) {
	.functions = ls( envir=xmapcore:::.xmap.queries )
	.queries = strsplit( .functions[ grep( func.pattern, .functions ) ], '\\.' )
	checkTrue( length( .queries ) >= min.len, paste( "Should have at least ", min.len, " '", func.type, "' functions", sep="" ) )
	r = lapply( .queries, function(i) {
		name = name.build.function( i )
		c( name, getFunction( name ) )
	} )
	r
}

.run.full.test.suite = function() {
	1 == length( grep( 'picr.man.ac.uk', Sys.info()[ 'nodename' ] ) )
}

.run.functions = function( functions, executor ) {
	lapply( c( 'hs-test' ), function( db ) {
		data = tryCatch( xmap.connect( db ), error=function(e) { FALSE } )
		if( length( data ) == 1 ) {
			print( paste( "Cannot find datasource '", db, "', so skipping these tests.", sep="" ) )
		}
		else {
			# Set this to true if this species has no arrays
			no.arrays = is.null( all.arrays( as.vector=F ) )
			lapply( functions, function( func ) {
				if( no.arrays && length( grep( "array|probe|hit|est_|prediction", func[[1]] ) ) == 1 ) {
					print( paste( "Skipping", func[[1]], "on", xmapcore:::.xmap.internals$db.name ) )
				}
				else {
					print( paste( "Running", func[[1]], "on", xmapcore:::.xmap.internals$db.name ) )
					tryCatch( executor( func[[1]], func[[2]] ), error=function(e) {
						traceback()
						print( e )
					} )
				}
			} )
		}
	} )
}

###############################################################################
## SetUp is called before each test method
##
.setUp = function() {
}

###############################################################################
## TearDown is called after each test method
##
.tearDown = function() {
	xmap.disconnect()
}

test.gotsomefunctions = function() {
  checkTrue( length( ls( envir=xmapcore:::.xmap.queries ) ) >= 96, "Should have at least 96 functions" )
}

test.all.queries = function() {
	if( .run.full.test.suite() ) {
		# Get all 'all' functions (of which there should be at least 14)
		.functions = .get.functions( 'all', '\\.all$', 14, function(i) { paste( 'all.', i[1], 's', sep="" ) } )
		# And run them, checking that we get at least one result from each
		.run.functions( .functions, function( name, f ) { r = f() ; checkTrue( length( r ) > 0, "Got no results!!" ) } )
	}
	else {
		print( '\nSkipping all.XXX tests, as not on a PICR machine' )
	}
}
